==> gravestones-1.2.3%2B1.20.4%2BA-sources.jar: net/pneumono/gravestones/block/AbstractGravestoneBlock.java <==
package net.pneumono.gravestones.block;

import net.minecraft.block.*;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2464;
import net.minecraft.class_247;
import net.minecraft.class_2470;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2754;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3737;
import org.jetbrains.annotations.Nullable;

import java.util.Objects;
import java.util.stream.Stream;

public abstract class AbstractGravestoneBlock extends class_2237 implements class_3737 {
    public static final class_2754<class_2350> FACING = class_2741.field_12481;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public AbstractGravestoneBlock(class_2251 settings) {
        super(settings);
        method_9590(method_9564()
                .method_11657(FACING, class_2350.field_11043)
                .method_11657(WATERLOGGED, false)
        );
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }

    //? if <1.20.6 {
    @SuppressWarnings("deprecation")
    //?}
    @Override
    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    @Override
    //? if >=1.21.3 {
    /*protected BlockState getStateForNeighborUpdate(BlockState state, WorldView world, ScheduledTickView tickView, BlockPos pos, Direction direction, BlockPos neighborPos, BlockState neighborState, Random random) {
        if (state.get(WATERLOGGED)) {
            tickView.scheduleFluidTick(pos, Fluids.WATER, Fluids.WATER.getTickRate(world));
        }

        return super.getStateForNeighborUpdate(state, world, tickView, pos, direction, neighborPos, neighborState, random);
    }
    *///?} else {
    //? if <1.20.6 {
    @SuppressWarnings("deprecation")
    //?}
    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (state.method_11654(WATERLOGGED)) {
            world.method_39281(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return super.method_9559(state, direction, neighborState, world, pos, neighborPos);
    }
    //?}

    @Nullable
    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return this.method_9564()
                .method_11657(FACING, Objects.requireNonNull(ctx.method_8036()).method_5735().method_10153())
                .method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_15772() == class_3612.field_15910);
    }

    //? if <1.20.6 {
    @SuppressWarnings("deprecation")
    //?}
    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    //? if <1.20.6 {
    @SuppressWarnings("deprecation")
    //?}
    @Override
    public class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return state.method_26186(mirror.method_10345(state.method_11654(FACING)));
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING);
        builder.method_11667(WATERLOGGED);
    }

    //? if <1.20.6 {
    @SuppressWarnings("deprecation")
    //?}
    @Override
    public class_265 method_9530(class_2680 state, class_1922 view, class_2338 pos, class_3726 context) {
        return switch (state.method_11654(FACING)) {
            case field_11034 -> SHAPE_E;
            case field_11035 -> SHAPE_S;
            case field_11039 -> SHAPE_W;
            default -> SHAPE_N;
        };
    }

    private static final class_265 SHAPE_N = Stream.of(
            class_2248.method_9541(1, 0, 10, 15, 2, 16),
            class_2248.method_9541(2, 2, 12, 14, 14, 14),
            class_2248.method_9541(4, 14, 12, 12, 16, 14)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
    private static final class_265 SHAPE_E = Stream.of(
            class_2248.method_9541(0, 0, 1, 6, 2, 15),
            class_2248.method_9541(2, 2, 2, 4, 14, 14),
            class_2248.method_9541(2, 14, 4, 4, 16, 12)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
    private static final class_265 SHAPE_S = Stream.of(
            class_2248.method_9541(1, 0, 0, 15, 2, 6),
            class_2248.method_9541(2, 2, 2, 14, 14, 4),
            class_2248.method_9541(4, 14, 2, 12, 16, 4)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
    private static final class_265 SHAPE_W = Stream.of(
            class_2248.method_9541(10, 0, 1, 16, 2, 15),
            class_2248.method_9541(12, 2, 2, 14, 14, 14),
            class_2248.method_9541(12, 14, 4, 14, 16, 12)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
}

==> gravestones-1.2.4%2B1.21.9%2BA-sources.jar: net/pneumono/gravestones/block/AbstractGravestoneBlock.java <==
package net.pneumono.gravestones.block;

import net.minecraft.block.*;
import net.minecraft.class_10225;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2464;
import net.minecraft.class_247;
import net.minecraft.class_2470;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2754;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import net.minecraft.class_3737;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import org.jetbrains.annotations.Nullable;

import java.util.Objects;
import java.util.stream.Stream;

public abstract class AbstractGravestoneBlock extends class_2237 implements class_3737 {
    public static final class_2754<class_2350> FACING = class_2741.field_12481;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public AbstractGravestoneBlock(class_2251 settings) {
        super(settings);
        method_9590(method_9564()
                .method_11657(FACING, class_2350.field_11043)
                .method_11657(WATERLOGGED, false)
        );
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }

    //? if <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    @Override
    //? if >=1.21.3 {
    protected class_2680 method_9559(class_2680 state, class_4538 world, class_10225 tickView, class_2338 pos, class_2350 direction, class_2338 neighborPos, class_2680 neighborState, class_5819 random) {
        if (state.method_11654(WATERLOGGED)) {
            tickView.method_64312(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return super.method_9559(state, world, tickView, pos, direction, neighborPos, neighborState, random);
    }
    //?} else {
    /*//? if <1.20.6 {
    /^@SuppressWarnings("deprecation")
    ^///?}
    public BlockState getStateForNeighborUpdate(BlockState state, Direction direction, BlockState neighborState, WorldAccess world, BlockPos pos, BlockPos neighborPos) {
        if (state.get(WATERLOGGED)) {
            world.scheduleFluidTick(pos, Fluids.WATER, Fluids.WATER.getTickRate(world));
        }

        return super.getStateForNeighborUpdate(state, direction, neighborState, world, pos, neighborPos);
    }
    *///?}

    @Nullable
    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return this.method_9564()
                .method_11657(FACING, Objects.requireNonNull(ctx.method_8036()).method_5735().method_10153())
                .method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_15772() == class_3612.field_15910);
    }

    //? if <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    //? if <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return state.method_26186(mirror.method_10345(state.method_11654(FACING)));
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING);
        builder.method_11667(WATERLOGGED);
    }

    //? if <1.20.6 {
    /*@SuppressWarnings("deprecation")
    *///?}
    @Override
    public class_265 method_9530(class_2680 state, class_1922 view, class_2338 pos, class_3726 context) {
        return switch (state.method_11654(FACING)) {
            case field_11034 -> SHAPE_E;
            case field_11035 -> SHAPE_S;
            case field_11039 -> SHAPE_W;
            default -> SHAPE_N;
        };
    }

    private static final class_265 SHAPE_N = Stream.of(
            class_2248.method_9541(1, 0, 10, 15, 2, 16),
            class_2248.method_9541(2, 2, 12, 14, 14, 14),
            class_2248.method_9541(4, 14, 12, 12, 16, 14)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
    private static final class_265 SHAPE_E = Stream.of(
            class_2248.method_9541(0, 0, 1, 6, 2, 15),
            class_2248.method_9541(2, 2, 2, 4, 14, 14),
            class_2248.method_9541(2, 14, 4, 4, 16, 12)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
    private static final class_265 SHAPE_S = Stream.of(
            class_2248.method_9541(1, 0, 0, 15, 2, 6),
            class_2248.method_9541(2, 2, 2, 14, 14, 4),
            class_2248.method_9541(4, 14, 2, 12, 16, 4)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
    private static final class_265 SHAPE_W = Stream.of(
            class_2248.method_9541(10, 0, 1, 16, 2, 15),
            class_2248.method_9541(12, 2, 2, 14, 14, 14),
            class_2248.method_9541(12, 14, 4, 14, 16, 12)
    ).reduce((v1, v2) -> class_259.method_1072(v1, v2, class_247.field_1366)).get();
}
